Class: Aws::ACMPCA::Types::CreateCertificateAuthorityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACMPCA::Types::CreateCertificateAuthorityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acmpca/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_authority_configuration ⇒ Types::CertificateAuthorityConfiguration
Name and bit size of the private key algorithm, the name of the signing algorithm, and X.500 certificate subject information.
-
#certificate_authority_type ⇒ String
The type of the certificate authority.
-
#idempotency_token ⇒ String
Custom string that can be used to distinguish between calls to the CreateCertificateAuthority action.
-
#key_storage_security_standard ⇒ String
Specifies a cryptographic key management compliance standard for handling and protecting CA keys.
-
#revocation_configuration ⇒ Types::RevocationConfiguration
Contains information to enable support for Online Certificate Status Protocol (OCSP), certificate revocation list (CRL), both protocols, or neither.
-
#tags ⇒ Array<Types::Tag>
Key-value pairs that will be attached to the new private CA.
-
#usage_mode ⇒ String
Specifies whether the CA issues general-purpose certificates that typically require a revocation mechanism, or short-lived certificates that may optionally omit revocation because they expire quickly.
Instance Attribute Details
#certificate_authority_configuration ⇒ Types::CertificateAuthorityConfiguration
Name and bit size of the private key algorithm, the name of the signing algorithm, and X.500 certificate subject information.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/aws-sdk-acmpca/types.rb', line 572 class CreateCertificateAuthorityRequest < Struct.new( :certificate_authority_configuration, :revocation_configuration, :certificate_authority_type, :idempotency_token, :key_storage_security_standard, :tags, :usage_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_authority_type ⇒ String
The type of the certificate authority.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/aws-sdk-acmpca/types.rb', line 572 class CreateCertificateAuthorityRequest < Struct.new( :certificate_authority_configuration, :revocation_configuration, :certificate_authority_type, :idempotency_token, :key_storage_security_standard, :tags, :usage_mode) SENSITIVE = [] include Aws::Structure end |
#idempotency_token ⇒ String
Custom string that can be used to distinguish between calls to the CreateCertificateAuthority action. Idempotency tokens for CreateCertificateAuthority time out after five minutes. Therefore, if you call CreateCertificateAuthority multiple times with the same idempotency token within five minutes, Amazon Web Services Private CA recognizes that you are requesting only certificate authority and will issue only one. If you change the idempotency token for each call, Amazon Web Services Private CA recognizes that you are requesting multiple certificate authorities.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/aws-sdk-acmpca/types.rb', line 572 class CreateCertificateAuthorityRequest < Struct.new( :certificate_authority_configuration, :revocation_configuration, :certificate_authority_type, :idempotency_token, :key_storage_security_standard, :tags, :usage_mode) SENSITIVE = [] include Aws::Structure end |
#key_storage_security_standard ⇒ String
Specifies a cryptographic key management compliance standard for handling and protecting CA keys.
Default: FIPS_140_2_LEVEL_3_OR_HIGHER
CCPC_LEVEL_1_OR_HIGHER for the KeyStorageSecurityStandard
parameter. If you don't, the operation returns an
InvalidArgsException with this message: "A certificate authority
cannot be created in this region with the specified security
standard."
For information about security standard support in different Amazon Web Services Regions, see Storage and security compliance of Amazon Web Services Private CA private keys.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/aws-sdk-acmpca/types.rb', line 572 class CreateCertificateAuthorityRequest < Struct.new( :certificate_authority_configuration, :revocation_configuration, :certificate_authority_type, :idempotency_token, :key_storage_security_standard, :tags, :usage_mode) SENSITIVE = [] include Aws::Structure end |
#revocation_configuration ⇒ Types::RevocationConfiguration
Contains information to enable support for Online Certificate Status Protocol (OCSP), certificate revocation list (CRL), both protocols, or neither. By default, both certificate validation mechanisms are disabled.
The following requirements apply to revocation configurations.
-
A configuration disabling CRLs or OCSP must contain only the
Enabled=Falseparameter, and will fail if other parameters such asCustomCnameorExpirationInDaysare included. -
In a CRL configuration, the
S3BucketNameparameter must conform to Amazon S3 bucket naming rules. -
A configuration containing a custom Canonical Name (CNAME) parameter for CRLs or OCSP must conform to RFC2396 restrictions on the use of special characters in a CNAME.
-
In a CRL or OCSP configuration, the value of a CNAME parameter must not include a protocol prefix such as "http://" or "https://".
For more information, see the OcspConfiguration and CrlConfiguration types.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/aws-sdk-acmpca/types.rb', line 572 class CreateCertificateAuthorityRequest < Struct.new( :certificate_authority_configuration, :revocation_configuration, :certificate_authority_type, :idempotency_token, :key_storage_security_standard, :tags, :usage_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Key-value pairs that will be attached to the new private CA. You can associate up to 50 tags with a private CA. For information using tags with IAM to manage permissions, see Controlling Access Using IAM Tags.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/aws-sdk-acmpca/types.rb', line 572 class CreateCertificateAuthorityRequest < Struct.new( :certificate_authority_configuration, :revocation_configuration, :certificate_authority_type, :idempotency_token, :key_storage_security_standard, :tags, :usage_mode) SENSITIVE = [] include Aws::Structure end |
#usage_mode ⇒ String
Specifies whether the CA issues general-purpose certificates that typically require a revocation mechanism, or short-lived certificates that may optionally omit revocation because they expire quickly. Short-lived certificate validity is limited to seven days.
The default value is GENERAL_PURPOSE.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/aws-sdk-acmpca/types.rb', line 572 class CreateCertificateAuthorityRequest < Struct.new( :certificate_authority_configuration, :revocation_configuration, :certificate_authority_type, :idempotency_token, :key_storage_security_standard, :tags, :usage_mode) SENSITIVE = [] include Aws::Structure end |