Class: Aws::ACMPCA::Types::LockoutPreventedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACMPCA::Types::LockoutPreventedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acmpca/types.rb
Overview
The current action was prevented because it would lock the caller out from performing subsequent actions. Verify that the specified parameters would not result in the caller being denied access to the resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
2029 2030 2031 2032 2033 |
# File 'lib/aws-sdk-acmpca/types.rb', line 2029 class LockoutPreventedException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |