Class: Aws::ACMPCA::Types::PolicyInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::ACMPCA::Types::PolicyInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-acmpca/types.rb
Overview
Defines the X.509 CertificatePolicies extension.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cert_policy_id ⇒ String
Specifies the object identifier (OID) of the certificate policy under which the certificate was issued.
-
#policy_qualifiers ⇒ Array<Types::PolicyQualifierInfo>
Modifies the given
CertPolicyIdwith a qualifier.
Instance Attribute Details
#cert_policy_id ⇒ String
Specifies the object identifier (OID) of the certificate policy under which the certificate was issued. For more information, see NIST's definition of Object Identifier (OID).
2218 2219 2220 2221 2222 2223 |
# File 'lib/aws-sdk-acmpca/types.rb', line 2218 class PolicyInformation < Struct.new( :cert_policy_id, :policy_qualifiers) SENSITIVE = [] include Aws::Structure end |
#policy_qualifiers ⇒ Array<Types::PolicyQualifierInfo>
Modifies the given CertPolicyId with a qualifier. Amazon Web
Services Private CA supports the certification practice statement
(CPS) qualifier.
2218 2219 2220 2221 2222 2223 |
# File 'lib/aws-sdk-acmpca/types.rb', line 2218 class PolicyInformation < Struct.new( :cert_policy_id, :policy_qualifiers) SENSITIVE = [] include Aws::Structure end |