Class: Aws::ACMPCA::Waiters::AuditReportCreated
- Inherits:
-
Object
- Object
- Aws::ACMPCA::Waiters::AuditReportCreated
- Defined in:
- lib/aws-sdk-acmpca/waiters.rb,
sig/waiters.rbs
Overview
Wait until a Audit Report is created
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AuditReportCreated
constructor
A new instance of AuditReportCreated.
-
#wait(params = {}) ⇒ Types::DescribeCertificateAuthorityAuditReportResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AuditReportCreated
Returns a new instance of AuditReportCreated.
87 88 |
# File 'lib/aws-sdk-acmpca/waiters.rb', line 87
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
124 125 126 |
# File 'lib/aws-sdk-acmpca/waiters.rb', line 124 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeCertificateAuthorityAuditReportResponse
Returns a response object which responds to the following methods:
- #audit_report_status => String
- #s3_bucket_name => String
- #s3_key => String
- #created_at => Time
119 |
# File 'lib/aws-sdk-acmpca/waiters.rb', line 119
def wait: (
|