Class: Aws::ACMPCA::Waiters::CertificateIssued

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-acmpca/waiters.rb,
sig/waiters.rbs

Overview

Wait until a certificate is issued

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ CertificateIssued

Returns a new instance of CertificateIssued.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 1
  • :before_attempt (Proc)
  • :before_wait (Proc)


185
186
# File 'lib/aws-sdk-acmpca/waiters.rb', line 185

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



220
221
222
# File 'lib/aws-sdk-acmpca/waiters.rb', line 220

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetCertificateResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :certificate_authority_arn (required, String)

    The Amazon Resource Name (ARN) that was returned when you called CreateCertificateAuthority. This must be of the form:

    arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 .

  • :certificate_arn (required, String)

    The ARN of the issued certificate. The ARN contains the certificate serial number and must be in the following form:

    arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012/certificate/286535153982981100925020015808220737245

Returns:



215
# File 'lib/aws-sdk-acmpca/waiters.rb', line 215

def wait: (